@@ -1,12 +1,12 @@
+"""Load the churn dataset, which can be used for binary classification problems."""
 import evalml
 from evalml.preprocessing import load_data
 
 
 def load_churn(n_rows=None, verbose=True):
-    """Load credit card fraud dataset.
-        The fraud dataset can be used for binary classification problems.
+    """Load churn dataset, which can be used for binary classification problems.
 
-    Arguments:
+    Args:
         n_rows (int): Number of rows from the dataset to return
         verbose (bool): Whether to print information about features and labels
 
@@ -14,7 +14,7 @@ def load_churn(n_rows=None, verbose=True):
         (pd.Dataframe, pd.Series): X and y
     """
     churn_data_path = (
-        "https://api.featurelabs.com/datasets/churn.csv?library=evalml&version="
+        "https://oss.alteryx.com/datasets/churn.csv?library=evalml&version="
         + evalml.__version__
     )
 
