@@ -16,8 +16,6 @@ class ElasticNetRegressor(Estimator):
         l1_ratio (float): The mixing parameter, with 0 <= l1_ratio <= 1. Only used if penalty='elasticnet'. Setting l1_ratio=0 is equivalent to using penalty='l2',
             while setting l1_ratio=1 is equivalent to using penalty='l1'. For 0 < l1_ratio <1, the penalty is a combination of L1 and L2. Defaults to 0.15.
         max_iter (int): The maximum number of iterations. Defaults to 1000.
-        normalize (boolean): If True, the regressors will be normalized before regression by subtracting the mean
-            and dividing by the l2-norm. Defaults to False.
         random_seed (int): Seed for the random number generator. Defaults to 0.
     """
 
@@ -46,7 +44,6 @@ class ElasticNetRegressor(Estimator):
         alpha=0.0001,
         l1_ratio=0.15,
         max_iter=1000,
-        normalize=False,
         random_seed=0,
         **kwargs,
     ):
@@ -54,7 +51,6 @@ class ElasticNetRegressor(Estimator):
             "alpha": alpha,
             "l1_ratio": l1_ratio,
             "max_iter": max_iter,
-            "normalize": normalize,
         }
         parameters.update(kwargs)
         en_regressor = SKElasticNet(random_state=random_seed, **parameters)
