@@ -1,4 +1,7 @@
 """Holt-Winters Exponential Smoothing Forecaster."""
+
+from typing import Dict, List, Optional, Union
+
 import numpy as np
 import pandas as pd
 from skopt.space import Integer
@@ -44,12 +47,12 @@ class ExponentialSmoothingRegressor(Estimator):
 
     def __init__(
         self,
-        trend=None,
-        damped_trend=False,
-        seasonal=None,
-        sp=2,
-        n_jobs=-1,
-        random_seed=0,
+        trend: Optional[str] = None,
+        damped_trend: bool = False,
+        seasonal: Optional[str] = None,
+        sp: int = 2,
+        n_jobs: int = -1,
+        random_seed: Union[int, float] = 0,
         **kwargs,
     ):
         if trend is None:
@@ -77,7 +80,7 @@ class ExponentialSmoothingRegressor(Estimator):
             random_seed=random_seed,
         )
 
-    def _remove_datetime(self, data):
+    def _remove_datetime(self, data: pd.DataFrame) -> pd.DataFrame:
         data_no_dt = data.copy()
         if isinstance(
             data_no_dt.index,
@@ -87,13 +90,13 @@ class ExponentialSmoothingRegressor(Estimator):
 
         return data_no_dt
 
-    def _set_forecast(self, X):
+    def _set_forecast(self, X: pd.DataFrame):
         from sktime.forecasting.base import ForecastingHorizon
 
         fh_ = ForecastingHorizon([i + 1 for i in range(len(X))], is_relative=True)
         return fh_
 
-    def fit(self, X, y=None):
+    def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
         """Fits Exponential Smoothing Regressor to data.
 
         Args:
@@ -115,7 +118,7 @@ class ExponentialSmoothingRegressor(Estimator):
         self._component_obj.fit(y=y)
         return self
 
-    def predict(self, X, y=None):
+    def predict(self, X: pd.DataFrame, y: Optional[pd.Series] = None) -> pd.Series:
         """Make predictions using fitted Exponential Smoothing regressor.
 
         Args:
@@ -133,7 +136,55 @@ class ExponentialSmoothingRegressor(Estimator):
         y_pred.name = None
         return infer_feature_types(y_pred)
 
+    def get_prediction_intervals(
+        self,
+        X: pd.DataFrame,
+        y: Optional[pd.Series] = None,
+        coverage: List[float] = None,
+    ) -> Dict[str, pd.Series]:
+        """Find the prediction intervals using the fitted ExponentialSmoothingRegressor.
+
+        Calculates the prediction intervals by using a simulation of the time series following a specified state space model.
+
+        Args:
+            X (pd.DataFrame): Data of shape [n_samples, n_features].
+            y (pd.Series): Target data. Optional.
+            coverage (List[float]): A list of floats between the values 0 and 1 that the upper and lower bounds of the
+                prediction interval should be calculated for.
+
+        Returns:
+            dict: Prediction intervals, keys are in the format {coverage}_lower or {coverage}_upper.
+        """
+        if coverage is None:
+            coverage = [0.95]
+        X, y = self._manage_woodwork(X, y)
+
+        # Accesses the fitted statsmodels model within sktime
+        # nsimulations represents how many steps should be simulated
+        # repetitions represents the number of simulations that should be run (confusing, I know)
+        # anchor represents where the simulations should start from (forecasting is done from the "end")
+        y_pred = self._component_obj._fitted_forecaster.simulate(
+            nsimulations=X.shape[0],
+            repetitions=400,
+            anchor="end",
+        )
+        prediction_interval_result = {}
+        for conf_int in coverage:
+            prediction_interval_lower = y_pred.quantile(
+                q=round((1 - conf_int) / 2, 3),
+                axis="columns",
+            )
+            prediction_interval_upper = y_pred.quantile(
+                q=round((1 + conf_int) / 2, 3),
+                axis="columns",
+            )
+            prediction_interval_lower.index = X.index
+            prediction_interval_upper.index = X.index
+            prediction_interval_result[f"{conf_int}_lower"] = prediction_interval_lower
+            prediction_interval_result[f"{conf_int}_upper"] = prediction_interval_upper
+        return prediction_interval_result
+
     @property
-    def feature_importance(self):
+    def feature_importance(self) -> pd.Series:
         """Returns array of 0's with a length of 1 as feature_importance is not defined for Exponential Smoothing regressor."""
         return pd.Series(np.zeros(1))
