@@ -7,6 +7,7 @@ import pytest
 
 from evalml.model_family import ModelFamily
 from evalml.pipelines.components import ARIMARegressor
+from evalml.preprocessing import split_data
 from evalml.problem_types import ProblemTypes
 
 pytestmark = [
@@ -129,7 +130,7 @@ def test_match_indices(ts_data):
 def test_set_forecast(ts_data):
     from sktime.forecasting.base import ForecastingHorizon
 
-    _, X_test, _ = ts_data(
+    X, X_test, _ = ts_data(
         train_features_index_dt=False,
         train_target_index_dt=False,
         train_none=False,
@@ -139,6 +140,7 @@ def test_set_forecast(ts_data):
     )
 
     clf = ARIMARegressor()
+    clf.last_X_index = X.index[-1]
     fh_ = clf._set_forecast(X_test)
     assert isinstance(fh_, ForecastingHorizon)
     assert len(fh_) == len(X_test)
@@ -233,7 +235,7 @@ def test_fit_predict(
     m_clf.fit(X=X_train, y=y_train)
     y_pred = m_clf.predict(X=X_test)
 
-    assert (y_pred_sk.values == y_pred.values).all()
+    np.testing.assert_almost_equal(y_pred_sk.values, y_pred.values)
     assert y_pred.index.equals(X_test.index)
 
 
@@ -330,7 +332,7 @@ def test_different_time_units_out_of_sample(
     y_pred = m_clf.predict(X=X[15:])
     assert m_clf._component_obj.d is None
 
-    assert (y_pred_sk.values == y_pred.values).all()
+    np.testing.assert_almost_equal(y_pred_sk.values, y_pred.values)
     assert y_pred.index.equals(X[15:].index)
 
 
@@ -385,11 +387,16 @@ def test_arima_boolean_features_no_error():
 
 
 @patch("sktime.forecasting.arima.AutoARIMA.fit")
-@patch("sktime.forecasting.arima.AutoARIMA.predict")
+@patch("sktime.forecasting.arima.AutoARIMA.predict_interval")
 def test_arima_regressor_respects_use_covariates(mock_predict, mock_fit, ts_data):
     X_train, X_test, y_train = ts_data()
     clf = ARIMARegressor(use_covariates=False)
 
+    mock_returned = pd.DataFrame({"lower": [1] * 10, "upper": [2] * 10})
+    mock_returned = pd.concat({0.95: mock_returned}, axis=1)
+    mock_returned = pd.concat({"Coverage": mock_returned}, axis=1)
+    mock_predict.return_value = mock_returned
+
     clf.fit(X_train, y_train)
     clf.predict(X_test)
     mock_fit.assert_called_once()
@@ -397,3 +404,71 @@ def test_arima_regressor_respects_use_covariates(mock_predict, mock_fit, ts_data
     assert "y" in mock_fit.call_args.kwargs
     mock_predict.assert_called_once()
     assert "X" not in mock_predict.call_args.kwargs
+
+
+@pytest.mark.parametrize("no_features", [True, False])
+def test_arima_regressor_prediction_intervals(no_features, ts_data):
+    X_train, X_test, y_train = ts_data(no_features=no_features)
+
+    clf = ARIMARegressor(use_covariates=not no_features)
+
+    clf.fit(X_train, y_train)
+    result = clf.predict(X_test)
+    result_95 = clf.get_prediction_intervals(X_test)
+
+    conf_ints = list(result_95.keys())
+    data = list(result_95.values())
+
+    mean_preds = pd.concat((data[0], data[1]), axis=1).mean(axis=1)
+
+    pd.testing.assert_series_equal(result, mean_preds)
+    pd.testing.assert_series_equal(clf.preds_95_lower, data[0])
+    pd.testing.assert_series_equal(clf.preds_95_upper, data[1])
+    assert len(conf_ints) == 2
+    assert len(data) == 2
+    assert conf_ints[0] == "0.95_lower"
+    assert conf_ints[1] == "0.95_upper"
+
+    coverages = [0.95, 0.90, 0.85]
+    results_coverage = clf.get_prediction_intervals(X_test, None, coverages)
+    predictions = clf.predict(X_test)
+
+    conf_ints = list(results_coverage.keys())
+    data = list(results_coverage.values())
+
+    assert len(conf_ints) == 6
+    assert len(data) == 6
+
+    for interval in coverages:
+        conf_int_lower = f"{interval}_lower"
+        conf_int_upper = f"{interval}_upper"
+
+        assert (results_coverage[conf_int_upper] > predictions).all()
+        assert (predictions > results_coverage[conf_int_lower]).all()
+        mean_preds = pd.concat(
+            (results_coverage[conf_int_lower], results_coverage[conf_int_upper]),
+            axis=1,
+        ).mean(axis=1)
+        pd.testing.assert_series_equal(mean_preds, predictions)
+
+
+@pytest.mark.parametrize("use_covariates", [True, False])
+def test_arima_regressor_can_forecast_arbitrary_dates(use_covariates, ts_data):
+    X, _, y = ts_data()
+
+    X_train, X_test, y_train, y_test = split_data(
+        X,
+        y,
+        problem_type="time series regression",
+        test_size=0.2,
+        random_seed=0,
+    )
+
+    X_test_last_5 = X_test.tail(5)
+
+    arima = ARIMARegressor(use_covariates=use_covariates)
+    arima.fit(X_train, y_train)
+
+    assert (
+        arima.predict(X_test).tail(5).tolist() == arima.predict(X_test_last_5).tolist()
+    )
