@@ -364,7 +364,6 @@ def test_describe_component():
             "alpha": 0.0001,
             "l1_ratio": 0.15,
             "max_iter": 1000,
-            "normalize": False,
         },
     }
     assert et_classifier.describe(return_dict=True) == {
@@ -399,7 +398,7 @@ def test_describe_component():
     }
     assert linear_regressor.describe(return_dict=True) == {
         "name": "Linear Regressor",
-        "parameters": {"fit_intercept": True, "normalize": False, "n_jobs": -1},
+        "parameters": {"fit_intercept": True, "n_jobs": -1},
     }
     assert svm_classifier.describe(return_dict=True) == {
         "name": "SVM Classifier",
@@ -1301,7 +1300,6 @@ def test_all_transformers_check_fit_input_type(
     make_data_type,
     ts_data,
 ):
-
     X, y = X_y_binary
     X = make_data_type(data_type, X)
     y = make_data_type(data_type, y)
@@ -1721,7 +1719,6 @@ def test_estimator_fit_respects_custom_indices(
     ts_data,
     helper_functions,
 ):
-
     supported_problem_types = estimator_class.supported_problem_types
 
     ts_problem = False
