@@ -261,7 +261,6 @@ def test_samplers_perform_equally(
 
 
 def test_smoten_categorical_boolean(X_y_binary, im):
-
     X, y = X_y_binary
     X.ww.set_types({0: "Categorical", 1: "Boolean"})
     X = X.drop(range(2, len(X.columns)), axis=1)
@@ -271,7 +270,6 @@ def test_smoten_categorical_boolean(X_y_binary, im):
 
 
 def test_smotenc_boolean_numeric(X_y_binary, im):
-
     X, y = X_y_binary
     X.ww.set_types({5: "Boolean", 12: "Boolean"})
     snc = Oversampler()
@@ -295,8 +293,9 @@ def test_smotenc_categorical_features(X_y_binary):
 
 def test_smotenc_category_features(X_y_binary):
     X, y = X_y_binary
+    X.columns = X.columns.astype(str)
     X = pd.DataFrame(X).rename({0: "postal", 1: "country"}, axis="columns")
-    X[2] = [i % 2 for i in range(X.shape[0])]
+    X["2"] = [i % 2 for i in range(X.shape[0])]
 
     # Replace postal and country features with plausible postal/country codes
     X["postal"] = np.arange(10001, 10001 + X.shape[0])
@@ -304,11 +303,15 @@ def test_smotenc_category_features(X_y_binary):
 
     X_ww = infer_feature_types(
         X,
-        feature_types={"postal": "PostalCode", "country": "CountryCode", 2: "Boolean"},
+        feature_types={
+            "postal": "PostalCode",
+            "country": "CountryCode",
+            "2": "Boolean",
+        },
     )
     snc = Oversampler()
     _ = snc.fit_transform(X_ww, y)
-    assert snc.categorical_features == [0, 1, 2]
+    assert snc.categorical_features == [20, 21, 2]
 
 
 def test_smotenc_output_shape(X_y_binary):
