@@ -10,7 +10,7 @@ from evalml.utils import SEED_BOUNDS, get_random_state
 
 
 def test_xgboost_regressor_random_seed_bounds_seed(X_y_regression):
-    """ensure xgboost's RNG doesn't fail for the min/max bounds we support on user-inputted random seeds"""
+    """ensure xgboost's RNG doesn't fail for the min/max bounds we support on user-inputted random seeds."""
     X, y = X_y_regression
     col_names = ["col_{}".format(i) for i in range(len(X[0]))]
     X.ww.columns = col_names
