@@ -446,7 +446,6 @@ def all_pipeline_classes():
     all_possible_pipeline_classes = []
     for estimator in _all_estimators():
         for problem_type in estimator.supported_problem_types:
-
             all_possible_pipeline_classes.append(
                 create_mock_pipeline(
                     estimator,
@@ -1987,7 +1986,9 @@ class _AutoMLTestEnv:
             new_callable=sleep_time,
         )
         if mock_predict_proba_in_sample is None:
-            with mock_sleep, mock_fit as fit, mock_score as score, mock_get_names as get_names, mock_encode_targets as encode, mock_predict_proba as proba, mock_tell as tell, mock_optimize as optimize:
+            with (
+                mock_sleep
+            ), mock_fit as fit, mock_score as score, mock_get_names as get_names, mock_encode_targets as encode, mock_predict_proba as proba, mock_tell as tell, mock_optimize as optimize:
                 # Can think of `yield` as blocking this method until the computation finishes running
                 yield
                 self._mock_fit = fit
@@ -1998,7 +1999,9 @@ class _AutoMLTestEnv:
                 self._mock_predict_proba = proba
                 self._mock_optimize_threshold = optimize
         else:
-            with mock_sleep, mock_fit as fit, mock_score as score, mock_get_names as get_names, mock_encode_targets as encode, mock_predict_proba as proba, mock_predict_proba_in_sample as proba_in_sample, mock_tell as tell, mock_optimize as optimize:
+            with (
+                mock_sleep
+            ), mock_fit as fit, mock_score as score, mock_get_names as get_names, mock_encode_targets as encode, mock_predict_proba as proba, mock_predict_proba_in_sample as proba_in_sample, mock_tell as tell, mock_optimize as optimize:
                 # Can think of `yield` as blocking this method until the computation finishes running
                 yield
                 self._mock_fit = fit
@@ -2129,7 +2132,6 @@ def dummy_data_check_name():
 
 @pytest.fixture
 def dummy_data_check_validate_output_warnings():
-
     return [
         {
             "message": "Data check dummy message",
@@ -2150,7 +2152,6 @@ def dummy_data_check_validate_output_warnings():
 
 @pytest.fixture
 def dummy_data_check_validate_output_errors():
-
     return [
         {
             "message": "Data check dummy message",
@@ -2312,3 +2313,27 @@ def generate_seasonal_data():
             return generate_real_data
 
     return _return_proper_func
+
+
+@pytest.fixture
+def categorical_floats_df():
+    X = pd.DataFrame(
+        {
+            "double_int_cats": pd.Series([1.0, 2.0, 3.0, 4.0, 5.0] * 20),
+            "string_cats": pd.Series(["a", "b", "c", "d", "e"] * 20),
+            "int_cats": pd.Series([1, 2, 3, 4, 5] * 20),
+            "int_col": pd.Series([1, 2, 3, 4, 5] * 20),
+            "double_col": pd.Series([1.2, 2.3, 3.9, 4.1, 5.5] * 20),
+        },
+    )
+    X.ww.init(
+        logical_types={
+            "double_int_cats": "Categorical",
+            "string_cats": "Categorical",
+            "int_cats": "Categorical",
+            "int_col": "Integer",
+            "double_col": "Double",
+        },
+    )
+
+    return X
